library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;

-- Toplevel module of comparator project.
--  * derive 4MHz and 4MHz/(SWITCH+1) clocks with corresponding synchronous resets from external clock and resets
--  * compare positive and negative input voltage (VP > VN?)
--  * register comparison with devided clock
--  
-- author: 
-- date:   
entity TOP is
  port (
    OSC_CLK     : in  std_logic;                    -- 48 MHz oscillator
    PO_RSTN     : in  std_logic;                    -- asynchronous power on reset (active low)
    PB_RSTN     : in  std_logic;                    -- asynchronous push button reset (active low)
    VP          : in  std_logic;                    -- positive comparator input
    VN          : in  std_logic;                    -- negative comparator input
    SWITCH      : in  std_logic_vector(3 downto 0); -- clock divider settings
    LED         : out std_logic_vector(3 downto 0); -- clock divider indication
    LOCK        : out std_logic;                    -- asynchronous PLL lock (active low)
    CLK         : out std_logic;                    -- 4 MHz
    RSTN        : out std_logic;                    -- synchronous reset (active low)
    DCLK        : out std_logic;                    -- 4/(SWITCH+1) MHz
    DRSTN       : out std_logic;                    -- synchronous reset (active low)
    COMPARE     : out std_logic);                   -- registered comparator output
end entity;
------------------------------------------------------------------------------------------------------------------------