library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;

library work;
use work.settings.all;

-- Controller for programmable gain amplifier
--  * transmit saturated gain request to PGA via SPI
--  * normalize sampled value by current gain setting
-- 
-- author: 
-- date:   
entity PGA_CONTROL is
  port (
    CLK        : in   std_logic;                                   -- 4 MHz clock
    RSTN       : in   std_logic;                                   -- synchronous reset (active low)
    GAIN       : in   std_logic_vector(             3 downto 0);   -- asynchronous gain request
    SCALED     : in   std_logic_vector(SAMPLE_WIDTH-1 downto 0);   -- sampled value of Vscaled 
    UNSCALED   : out  std_logic_vector(SAMPLE_WIDTH+3 downto 0);   -- sampled value of Vin
    SCK        : out  std_logic;                                   -- SPI clock
    SDI        : out  std_logic;                                   -- SPI data
    CSN        : out  std_logic);                                  -- SPI chip select (active low) 
end entity;
------------------------------------------------------------------------------------------------------------------------