library ieee;
use ieee.std_logic_1164.all;

library igloo;
use igloo.all;

-- Static phase-locked loop
--  * derive 4 MHz clock from 48 MHz oscillator
-- 
-- author: Andreas Engel
-- data:   03/13
entity PLL48M is
  port( 
      POWERDOWN : in  std_logic;    -- asynchronous reset (active low)
      CLKA      : in  std_logic;    -- 48 MHz oscillator input
      LOCK      : out std_logic;    -- asynchronous output stable signal (active high) 
      GLA       : out std_logic);   -- 4 MHz output clock
end entity;
------------------------------------------------------------------------------------------------------------------------

architecture arch of PLL48M is 

  component PLL
    generic (
      VCOFREQUENCY : real := 0.0);
    port( 
      CLKA      : in    std_logic := 'U';
      EXTFB     : in    std_logic := 'U';
      POWERDOWN : in    std_logic := 'U';
      GLA       : out   std_logic;
      LOCK      : out   std_logic;
      GLB       : out   std_logic;
      YB        : out   std_logic;
      GLC       : out   std_logic;
      YC        : out   std_logic;
      OADIV0    : in    std_logic := 'U';
      OADIV1    : in    std_logic := 'U';
      OADIV2    : in    std_logic := 'U';
      OADIV3    : in    std_logic := 'U';
      OADIV4    : in    std_logic := 'U';
      OAMUX0    : in    std_logic := 'U';
      OAMUX1    : in    std_logic := 'U';
      OAMUX2    : in    std_logic := 'U';
      DLYGLA0   : in    std_logic := 'U';
      DLYGLA1   : in    std_logic := 'U';
      DLYGLA2   : in    std_logic := 'U';
      DLYGLA3   : in    std_logic := 'U';
      DLYGLA4   : in    std_logic := 'U';
      OBDIV0    : in    std_logic := 'U';
      OBDIV1    : in    std_logic := 'U';
      OBDIV2    : in    std_logic := 'U';
      OBDIV3    : in    std_logic := 'U';
      OBDIV4    : in    std_logic := 'U';
      OBMUX0    : in    std_logic := 'U';
      OBMUX1    : in    std_logic := 'U';
      OBMUX2    : in    std_logic := 'U';
      DLYYB0    : in    std_logic := 'U';
      DLYYB1    : in    std_logic := 'U';
      DLYYB2    : in    std_logic := 'U';
      DLYYB3    : in    std_logic := 'U';
      DLYYB4    : in    std_logic := 'U';
      DLYGLB0   : in    std_logic := 'U';
      DLYGLB1   : in    std_logic := 'U';
      DLYGLB2   : in    std_logic := 'U';
      DLYGLB3   : in    std_logic := 'U';
      DLYGLB4   : in    std_logic := 'U';
      OCDIV0    : in    std_logic := 'U';
      OCDIV1    : in    std_logic := 'U';
      OCDIV2    : in    std_logic := 'U';
      OCDIV3    : in    std_logic := 'U';
      OCDIV4    : in    std_logic := 'U';
      OCMUX0    : in    std_logic := 'U';
      OCMUX1    : in    std_logic := 'U';
      OCMUX2    : in    std_logic := 'U';
      DLYYC0    : in    std_logic := 'U';
      DLYYC1    : in    std_logic := 'U';
      DLYYC2    : in    std_logic := 'U';
      DLYYC3    : in    std_logic := 'U';
      DLYYC4    : in    std_logic := 'U';
      DLYGLC0   : in    std_logic := 'U';
      DLYGLC1   : in    std_logic := 'U';
      DLYGLC2   : in    std_logic := 'U';
      DLYGLC3   : in    std_logic := 'U';
      DLYGLC4   : in    std_logic := 'U';
      FINDIV0   : in    std_logic := 'U';
      FINDIV1   : in    std_logic := 'U';
      FINDIV2   : in    std_logic := 'U';
      FINDIV3   : in    std_logic := 'U';
      FINDIV4   : in    std_logic := 'U';
      FINDIV5   : in    std_logic := 'U';
      FINDIV6   : in    std_logic := 'U';
      FBDIV0    : in    std_logic := 'U';
      FBDIV1    : in    std_logic := 'U';
      FBDIV2    : in    std_logic := 'U';
      FBDIV3    : in    std_logic := 'U';
      FBDIV4    : in    std_logic := 'U';
      FBDIV5    : in    std_logic := 'U';
      FBDIV6    : in    std_logic := 'U';
      FBDLY0    : in    std_logic := 'U';
      FBDLY1    : in    std_logic := 'U';
      FBDLY2    : in    std_logic := 'U';
      FBDLY3    : in    std_logic := 'U';
      FBDLY4    : in    std_logic := 'U';
      FBSEL0    : in    std_logic := 'U';
      FBSEL1    : in    std_logic := 'U';
      XDLYSEL   : in    std_logic := 'U';
      VCOSEL0   : in    std_logic := 'U';
      VCOSEL1   : in    std_logic := 'U';
      VCOSEL2   : in    std_logic := 'U');
  end component;

  component PLLINT
    port( 
      A : in    std_logic := 'U';
      Y : out   std_logic);
  end component;
  
  signal s_clka : std_logic;

begin 

    
    i_pllint : PLLINT port map (CLKA, s_clka);
    
    i_pll : PLL
      generic map(32.0)
      port map(
        CLKA      => s_clka, 
        EXTFB     => '0', 
        POWERDOWN => POWERDOWN, 
        GLA       => GLA, 
        LOCK      => LOCK, 
        GLB       => OPEN, 
        YB        => OPEN, 
        GLC       => OPEN, 
        YC        => OPEN, 
        
        OADIV0    => '1', 
        OADIV1    => '1', 
        OADIV2    => '1', 
        OADIV3    => '0', 
        OADIV4    => '0', 
        
        OAMUX0    => '0', 
        OAMUX1    => '0', 
        OAMUX2    => '1', 
        
        DLYGLA0   => '0', 
        DLYGLA1   => '0', 
        DLYGLA2   => '0', 
        DLYGLA3   => '0', 
        DLYGLA4   => '0', 
        
        OBDIV0    => '0', 
        OBDIV1    => '0', 
        OBDIV2    => '0', 
        OBDIV3    => '0', 
        OBDIV4    => '0', 
        
        OBMUX0    => '0', 
        OBMUX1    => '0', 
        OBMUX2    => '0', 
        
        DLYYB0    => '0', 
        DLYYB1    => '0', 
        DLYYB2    => '0', 
        DLYYB3    => '0', 
        DLYYB4    => '0', 
        
        DLYGLB0   => '0', 
        DLYGLB1   => '0', 
        DLYGLB2   => '0', 
        DLYGLB3   => '0', 
        DLYGLB4   => '0', 
        
        OCDIV0    => '0', 
        OCDIV1    => '0', 
        OCDIV2    => '0', 
        OCDIV3    => '0', 
        OCDIV4    => '0', 
        
        OCMUX0    => '0', 
        OCMUX1    => '0', 
        OCMUX2    => '0', 
        
        DLYYC0    => '0', 
        DLYYC1    => '0', 
        DLYYC2    => '0', 
        DLYYC3    => '0', 
        DLYYC4    => '0', 
        
        DLYGLC0   => '0', 
        DLYGLC1   => '0', 
        DLYGLC2   => '0', 
        DLYGLC3   => '0', 
        DLYGLC4   => '0', 
        
        FINDIV0   => '0', 
        FINDIV1   => '0', 
        FINDIV2   => '0', 
        FINDIV3   => '1', 
        FINDIV4   => '0', 
        FINDIV5   => '0', 
        FINDIV6   => '0', 
        
        FBDIV0    => '1', 
        FBDIV1    => '0', 
        FBDIV2    => '1', 
        FBDIV3    => '0', 
        FBDIV4    => '0', 
        FBDIV5    => '0', 
        FBDIV6    => '0', 
        
        FBDLY0    => '0', 
        FBDLY1    => '0', 
        FBDLY2    => '0', 
        FBDLY3    => '0', 
        FBDLY4    => '0', 
        
        FBSEL0    => '1', 
        FBSEL1    => '0', 
        
        XDLYSEL   => '0', 
        
        VCOSEL0   => '1', 
        VCOSEL1   => '1', 
        VCOSEL2   => '0');
    
end architecture; 