`default_nettype none

// UART transmitter
//  * forward transmission interface of general UART core
//  * baudrate = CLK / (2*baudvalue+16)
// 
// author: Andreas Engel
// date:   03/13
module UTX 
 (input  wire        CLK,          // clock                                            
  input  wire        RSTN,         // synchronous reset (active low)                   
  input  wire [15:0] BAUD_VALUE,   // communication speed configuration                
  input  wire [ 7:0] D,            // byte to transmit                                 
  input  wire        WEN,          // synchronous UART write enable (active low)       
  output wire        RDY,          // synchronous UART ready confirmation (active high)
  output wire        TX);          // UART output data                                 
/**********************************************************************************************************************/

COREUART #(
  .BAUD_VAL_FRCTN_EN ( 1),
  .FAMILY            (20),
  .RX_FIFO           ( 0),
  .RX_LEGACY_MODE    ( 0),
  .TX_FIFO           ( 0))
i_uart (
  .CLK               (CLK),
  .RESET_N           (RSTN),
  .DATA_IN           (D),
  .WEN               (WEN),
  .TXRDY             (RDY),
  .TX                (TX),
  .BAUD_VAL          (BAUD_VALUE[15:3]),
  .BAUD_VAL_FRACTION (BAUD_VALUE[ 2:0]),
  
  .CSN               (1'b0),
  .ODD_N_EVEN        (1'b0),
  .OEN               (1'b1),
  .PARITY_EN         (1'b0),
  .RX                (1'b1),
  .BIT8              (1'b1),
  .RXRDY             (),
  .PARITY_ERR        (),
  .OVERFLOW          (),
  .FRAMING_ERR       (),
  .DATA_OUT          ());

endmodule
